delete_groups_query = '''
	mutation deleteGroups($groupPks: [Int!]!) {
        deleteGroups(input: {groupPks: $groupPks}) {
            succeeded
            failed {
                groupPk
                message
                code
            }
            error {
                message
                code
            }
        }
    }
'''

create_group_query = '''
	mutation createTeam($name: String!) {
        createTeam(input: {name: $name}) {
            ok
            team {
                pk
                name
            }
            error {
                message
                code
            }
        }
    }
'''

add_members_query = '''
	mutation addMembersToTeam($teamPk: Int!, $emails: [String]!) {
        addMembersToTeam(input: {teamPk: $teamPk, emails: $emails}) {
            succeeded {
                pk
                email
            }
            failed {
                email
                message
                code
            }
            team {
                members {
                    edges {
                        node {
                            pk
                            email
                        }
                    }
                }
            }
        }
    }
'''

remove_members_query = '''
	mutation removeMembersFromTeam($teamPk: Int!, $emails: [String]!) {
        removeMembersFromTeam(input: {teamPk: $teamPk, emails: $emails}) {
            succeeded
            failed {
                email
                message
                code
            }
            team {
                members {
                    edges {
                        node {
                            pk
                            email
                        }
                    }
                }
            }
        }
    }
'''

update_group_name_query = '''
    mutation updateGroup($pk: Int!, $name: String!) {
        updateGroup(input: {pk: $pk, name: $name}) {
            ok
            error {
                message
                code
            }
            team {
                pk
            }
        }
    }
'''




import click

from marvelcli import utils
from marvelcli.folder import folder_queries

# Limited by the API to only be able to create folders at the moment.

@click.option('-n', '--name', type=str, help='Name of folder')
@click.option('-v', '--visibility', type=str, help='`workspace` by default, use this flag with `private` for a private folder ')
@click.option('-a', '--auth', type=str, help='Auth your request')
@click.command()
def create_folder(name: str, visibility: str, auth: str):
	"""Create a folder"""
	if not visibility:
		visibility = 'WORKSPACE'
	params = {'name': name, 'visibility': visibility.upper()}
	query = folder_queries.create_folder_query
	r, json_data = utils.make_request(auth, query, params)

	if r.status_code == 200:
		if not json_data['data']['createFolder']['ok']:
			click.echo('\n' + json_data['data']['createFolder']['error']['message'] + '\n')
		else:
			click.echo('\nThe %s folder "%s" has been successfully created in your Marvel account\n' % (visibility.lower(), name))
	else:
		click.echo("\nTry 'marvelcli create-folder --help' to make sure you are not missing any args.\n")



create_folder_query = '''
	mutation createFolder($name: String!, $visibility: FolderVisibilityEnum) {
        createFolder(input: {name: $name, visibility: $visibility}) {
            ok
            folder {
                pk
                name
                companyPk
                visibility
            }
            error {
                message
                code
            }
        }
    }
'''



import requests
import json
import os

def api_request(access_token, query, params=None):
	base_url = 'https://marvelapp.com/graphql'
	return requests.post(
		base_url,
		headers={'Authorization': 'Bearer {}'.format(access_token)},
		json={'query': query, 'variables': params}
	)

def get_access_token(auth=None):
	if auth:
		access_token = auth
		os.environ['MARVEL_CLI_TOKEN'] = access_token
	elif os.environ.get('MARVEL_CLI_TOKEN'):
		access_token = os.environ.get('MARVEL_CLI_TOKEN')
	else:
		access_token = input("Your auth code: ")
		os.environ['MARVEL_CLI_TOKEN'] = access_token

	return access_token

def make_request(auth, query, params=None):
	access_token = get_access_token(auth)
	if not params:
		r = api_request(access_token, query)
	else:
		r = api_request(access_token, query, params)
	json_data = json.loads(r.text)

	return r, json_data

class colour:
   PURPLE = '\033[95m'
   CYAN = '\033[96m'
   DARKCYAN = '\033[36m'
   BLUE = '\033[94m'
   GREEN = '\033[92m'
   YELLOW = '\033[93m'
   RED = '\033[91m'
   BOLD = '\033[1m'
   UNDERLINE = '\033[4m'
   END = '\033[0m'



get_billing_info_query = '''
	query user {
  		user {
		  	company {
			    billing {
				    plan {
				    	teamMembers
				        title
				        priceYearly
				        priceMonthly
				    }
				    billingCycle
				    seatQuantityPurchased
				    seatQuantityUsed
				    seats {
				        originallyPurchased
				        payingFor
				        limit
				    }
				    payment
				    projectQuantityUsed
				    nextPaymentDate
				    currency
			    }
			}
		}
	}
'''

remove_users_from_workspace_query = '''
    mutation removeUsersFromWorkspace($emails: [String!]!,) {
        removeUsersFromWorkspace(input: {emails: $emails,}) {
                succeeded
                failed {
                    email
                    message
                    code
                }
                error {
                    message
                    code
                    email
                }
            }
        }
    '''



import click
import datetime

from marvelcli import utils
from marvelcli.user import user_queries

@click.option('-a', '--auth', help='Auth your request')
@click.command()
def about_user(auth: str):
	"""User statistics"""
	query = user_queries.about_user_query
	r, json_data = utils.make_request(auth, query)

	if r.status_code != 200:
		click.echo("\nWe could not retrieve the data at this time, possibly due to a ratelimit. Try again in a few minutes\n")
	else:
		user = json_data['data']['user']
		last_active = user['lastActiveAt']
		last_active = datetime.datetime(int(last_active[0:4]), int(last_active[5:7]), int(last_active[8:10]), 0, 0)

		click.echo(utils.colour.BOLD + '\nYour Account:' + utils.colour.END)
		click.echo('Email: %s' % user['email'])
		click.echo('Last Active: %s' % last_active)
		click.echo('Status: %s' % user['status'])
		click.echo('Username: %s \n' % user['username'])



import click
import datetime

from marvelcli import utils
from marvelcli.workspace import workspace_queries

@click.option('-e', '--email', type=str, multiple=True, help='Use this flag for each email address you want removed from your workspace')
@click.option('-a', '--auth', type=str, help='Auth your request')
@click.command()
def remove_users_from_workspace(email: list, auth: str):
	"""Remove users from your workspace"""
	params = {'emails': email}
	query = workspace_queries.remove_users_from_workspace_query
	r, json_data = utils.make_request(auth, query, params)

	if not email:
		click.echo('Looks like you are missing some args, add `--help` to the command to see the options')
	if r.status_code != 200:
		if not email:
			click.echo('Looks like you are missing some args, add `--help` to the command to see the options')
		else:
			click.echo('\n' + json_data['data']['removeUsersFromWorkspace']['error']['message'] + '\n')
	else:
		data_success = json_data['data']['removeUsersFromWorkspace']['succeeded']
		data_failed = json_data['data']['removeUsersFromWorkspace']['failed']

		if data_success:
			succeeded = "\nThe following people were successfully removed from your workspace: %s \n" % ', '.join(data_success)
			click.echo(succeeded)

		if data_failed:
			click.echo('\nThe following people could not be removed from your workspace:')
			for f in data_failed:
				click.echo("%s  - '%s'\n" % (f.get('email'), f.get('message')))


@click.option('-a', '--auth', type=str, help='Auth your request')
@click.command()
def get_billing_info(auth: str):
	"""Get billing information"""
	query = workspace_queries.get_billing_info_query
	r, json_data = utils.make_request(auth, query)

	if r.status_code != 200:
		click.echo('\n' + 'Billing data could not be returned right now.' + '\n')
	else:
		billing = json_data['data']['user']['company']['billing']
		plan = billing['plan']

		if billing['billingCycle'] == 'yearly':
			price = int(plan['priceYearly'] / 100)
			price_per_seat = round(price / billing['seatQuantityUsed'], 2)
		else:
			price = int(plan['priceMonthly'] / 100)
			price_per_seat = round(price / billing['seatQuantityUsed'], 2)

		click.echo(utils.colour.BOLD + "\nYour Plan" + utils.colour.END)
		click.echo("Type: %s" % plan['title'])
		if plan['title'] != 'Free':
			click.echo("Price: %s %s" % (price, billing['currency'].upper()))
			click.echo("Seats: %s (%s %s per user)" % (plan['teamMembers'], price_per_seat, billing['currency'].upper()))
			click.echo("Projects: Unlimited \n")
		else:
			click.echo("Seats: %s " % (plan['teamMembers']))
			click.echo("Projects: 1 \n")

		click.echo(utils.colour.BOLD + "Your Usage" + utils.colour.END)
		click.echo("Seats Purchased: %s" % billing['seatQuantityPurchased'])
		click.echo("Seats Used: %s" % billing['seatQuantityUsed'])
		click.echo("Projects: %s \n" % billing['projectQuantityUsed'])

		if plan['title'] != 'Free':
			next_payment_date = billing['nextPaymentDate']
			dt = datetime.datetime(int(next_payment_date[0:4]), int(next_payment_date[5:7]), int(next_payment_date[8:10]), 0, 0)
			next_payment_date = "%s-%s-%s" % (dt.day, dt.month, dt.year)
			next_payment_amount = price_per_seat * billing['seatQuantityPurchased']
			click.echo("Your next payment date is %s. You'll be paying %s %s for %s seats.\n" % (next_payment_date, next_payment_amount, billing['currency'].upper(), billing['seatQuantityPurchased']))
		else:
			click.echo("Upgrade to create more projects and add more team members: https://marvelapp.com/plans\n")



delete_project_query = '''
	mutation deleteproject ($pk: Int!) {
		deleteProject(input: {pk: $pk}) {
            ok
        }
    }
'''

create_project_query = '''
	mutation createproject ($name: String!, $password: String!) {
		createProject(input: {name: $name, password: $password}) {
            ok
        }
    }
'''

add_collabs_to_project_query = '''
    mutation addCollaboratorsToProject ($projectPk: Int!, $emails: [String]!){
        addCollaboratorsToProject(input: {projectPk: $projectPk, emails: $emails}) {
            failed {
                email
                message
                code
            }
            succeeded {
                email
            }
            project {
                pk
            }
        }
    }
'''

remove_collabs_from_project_query = '''
    mutation removeCollaboratorsFromProject ($projectPk: Int!, $emails: [String]!){
        removeCollaboratorsFromProject(input: {projectPk: $projectPk, emails: $emails}) {
            failed {
                email
                message
                code
            }
            succeeded
            project {
                pk
            }
        }
    }
'''

get_all_personal_projects_query = '''
    query {
        user {
            projects {
                edges {
                    node {
                        prototypeUrl
                    }
                }
            }
        }
    }
'''

add_groups_to_project_query = '''
    mutation addTeamsToProject($projectPk: Int!, $teamPks: [Int!]!) {
        addTeamsToProject(input: {projectPk: $projectPk, teamPks: $teamPks}) {
            project {
                pk
            }
            succeeded {
                pk
            }
            failed {
                teamPk
                message
                code
            }
            error {
                message
                code
                teamPk
            }
        }
    }
'''

remove_groups_from_project_query = '''
    mutation removeTeamsFromProject($projectPk: Int!, $teamPks: [Int!]!) {
        removeTeamsFromProject(input: {projectPk: $projectPk, teamPks: $teamPks}) {
            project {
                pk
            }
            succeeded {
                pk
            }
            failed {
                teamPk
                message
                code
            }
            error {
                message
                code
                teamPk
            }
        }
    }
'''



#!/usr/bin/env python3
import click
import json
import datetime

from marvelcli import utils
from marvelcli.user import user_commands
from marvelcli.workspace import workspace_commands
from marvelcli.project import project_commands
from marvelcli.folder import folder_commands
from marvelcli.group import group_commands

@click.group()
def marvelcli(args=None):
    """A CLI wrapper for Marvelapp

	The wrapper will enable you to interact with your Marvel
	account from the comfort of your command line.

	You will need an access token to use the CLI, generate a
	new one or find the one you already have set up here:
	https://marvelapp.com/oauth/devtoken

	You can export your token by running this command from the
	same dir you installed the CLI:
	`export MARVEL_CLI_TOKEN='your access token'`

	"""

# User
marvelcli.add_command(user_commands.about_user)

# Workspace
marvelcli.add_command(workspace_commands.get_billing_info)
marvelcli.add_command(workspace_commands.remove_users_from_workspace)

# Project
marvelcli.add_command(project_commands.delete_project)
marvelcli.add_command(project_commands.create_project)
marvelcli.add_command(project_commands.add_groups_to_project)
marvelcli.add_command(project_commands.remove_groups_from_project)
marvelcli.add_command(project_commands.add_collabs_to_project)
marvelcli.add_command(project_commands.remove_collabs_from_project)
marvelcli.add_command(project_commands.get_personal_projects)

# Group
marvelcli.add_command(group_commands.delete_groups)
marvelcli.add_command(group_commands.create_group)
marvelcli.add_command(group_commands.add_members_to_group)
marvelcli.add_command(group_commands.remove_members_from_group)
marvelcli.add_command(group_commands.update_group_name)

# Folder - limited by the API
marvelcli.add_command(folder_commands.create_folder)

if __name__ == "__main__":
	marvelcli()



import click
import json

from marvelcli import utils
from marvelcli.project import project_queries
from marvelcli.workspace import workspace_queries

@click.option('-p', '--project-pk', type=str, help='Pk of the project you want to delete')
@click.option('-a', '--auth', type=str, help='Auth your request')
@click.command()
def delete_project(project_pk: str, auth: str):
	"""Delete a project"""
	params = {'pk': project_pk}
	query = project_queries.delete_project_query
	r, json_data = utils.make_request(auth, query, params)

	if r.status_code == 200:
		if json_data['data']['deleteProject'] is None:
			click.echo("\nProject '%s' has not been deleted for the following reason: %s\n" % (
				project_pk,
				json_data['errors'][0]['message']
			))
		else:
			click.echo("\n'%s' has been successfully deleted from your Marvel account\n" % project_pk)
	else:
		click.echo("\nTry 'marvelcli delete_project --help' to make sure you are not missing any args.\n")

@click.option('-p', '--project-pk', type=int, help='Pk of the project you want to add groups to')
@click.option('-g', '--group-pk', type=int, multiple=True, help='Use this flag for each group you want added to your project')
@click.option('-a', '--auth', type=str, help='Auth your request')
@click.command()
def add_groups_to_project(project_pk: int, group_pk: list, auth: str):
	"""Add groups to a project"""
	params = {'projectPk': project_pk,'teamPks': group_pk}
	query = project_queries.add_groups_to_project_query
	r, json_data = utils.make_request(auth, query, params)

	if r.status_code != 200:
		if not project_pk or not group_pk:
			click.echo("\nLooks like you might be missing some args, add `--help` to your command to see the options.\n")
		else:
			click.echo('\n' + json_data['data']['addTeamsToProject']['error']['message'] + '\n')
	else:
		data_success = json_data['data']['addTeamsToProject']['succeeded']
		data_failed = json_data['data']['addTeamsToProject']['failed']

		if data_success:
			successful_groups = []
			for s in data_success:
				successful_groups.append(s.get('pk'))
			click.echo("\nThe following groups were successfully added to project %s: %s \n" % (project_pk, successful_groups))

		if data_failed:
			click.echo('\nThe following groups could not be added to project %s:' % (project_pk))
			for f in data_failed:
				click.echo("%s  - %s" % (f.get('teamPk'), f.get('message')))

		click.echo("\n")

@click.option('-p', '--project-pk', type=int, help='Pk of the project you want to remove groups from')
@click.option('-g', '--group_pk', type=int, multiple=True, help='Use this flag for each group you want removed from your project')
@click.option('-a', '--auth', type=str, help='Auth your request')
@click.command()
def remove_groups_from_project(project_pk: int, group_pk: list, auth: str):
	"""Remove groups from a project"""
	params = {'projectPk': project_pk,'teamPks': group_pk}
	query = project_queries.remove_groups_from_project_query
	r, json_data = utils.make_request(auth, query, params)

	if r.status_code != 200:
		if not project_pk or not group_pk:
			click.echo("\nLooks like you might be missing some args, add `--help` to your command to see the options.\n")
		else:
			click.echo('\n' + json_data['data']['removeTeamsFromProject']['error']['message'] + '\n')
	else:
		data_success = json_data['data']['removeTeamsFromProject']['succeeded']
		data_failed = json_data['data']['removeTeamsFromProject']['failed']

		if data_success:
			successful_groups = []
			for s in data_success:
				successful_groups.append(s.get('pk'))
			click.echo("\nThe following groups were successfully removed from project %s: %s\n" % (project_pk, successful_groups))

		if data_failed:
			click.echo('\nThe following groups could not be removed from project %s:' % (project_pk))
			for f in data_failed:
				click.echo("%s  - %s" % (f.get('teamPk'), f.get('message')))

		click.echo("\n")

@click.option('-p', '--project-pk', type=int, help='Pk of the project you want to add collaborators to')
@click.option('-e', '--email', type=str, multiple=True, help='Use this flag for each email address you want added to your project')
@click.option('-a', '--auth', type=str, help='Auth your request')
@click.command()
def add_collabs_to_project(project_pk: int, email: list, auth: str):
	"""Add collaborators to a project"""
	params = {'projectPk': project_pk,'emails': email}
	query = project_queries.add_collabs_to_project_query
	r, json_data = utils.make_request(auth, query, params)

	if r.status_code != 200:
		if not project_pk:
			click.echo("\nLooks like you might be missing some args, add `--help` to your command to see the options.\n")
		else:
			click.echo('\n' + json_data['data']['addCollaboratorsToProject']['error']['message'] + '\n')
	else:
		# status_code 200 without all args
		if not email:
			click.echo("\nLooks like you might be missing some args, add `--help` to your command to see the options.\n")
		else:
			data_success = json_data['data']['addCollaboratorsToProject']['succeeded']
			data_failed = json_data['data']['addCollaboratorsToProject']['failed']

			if data_success:
				successful_emails = []
				for s in data_success:
					successful_emails.append(s.get('email'))
				click.echo("\nThe following people were successfully added to project %s: %s" % (project_pk, ', '.join(successful_emails)))

			if data_failed:
				click.echo('\nThe following people could not be added to project %s for the following reasons:' % (project_pk))
				for f in data_failed:
					click.echo("%s  - '%s'" % (f.get('email'), f.get('message')))

			click.echo("\n")


@click.option('-p', '--project-pk', type=int, help='Pk of the project you want to remove collaborators from')
@click.option('-e', '--email', type=str, multiple=True, help='Use this flag for each email address you want removed from your project')
@click.option('-a', '--auth', type=str, help='Auth your request')
@click.command()
def remove_collabs_from_project(project_pk: int, email: list, auth: str):
	"""Remove collaborators from a project"""
	params = {'projectPk': project_pk,'emails': email}
	query = project_queries.remove_collabs_from_project_query
	r, json_data = utils.make_request(auth, query, params)

	if r.status_code != 200:
		if not project_pk:
			click.echo("\nLooks like you might be missing some args, add `--help` to your command to see the options.\n")
		else:
			click.echo('\n' + json_data['data']['removeCollaboratorsFromProject']['error']['message'] + '\n')
	else:
		if not email:
			click.echo("\nLooks like you might be missing some args, add `--help` to your command to see the options.\n")
		else:
			data_success = json_data['data']['removeCollaboratorsFromProject']['succeeded']
			if json_data['data']['removeCollaboratorsFromProject']['succeeded']:
				click.echo("\nThe following people were successfully removed from project %s: %s" % (project_pk, data_success))

			data_failed = json_data['data']['removeCollaboratorsFromProject']['failed']
			if data_failed:
				click.echo('\nThe following people could not be removed from project %s for the following reasons:' % (project_pk))
				for f in data_failed:
					click.echo("%s  - '%s'" % (f.get('email'), f.get('message')))

			click.echo("\n")


@click.option('-n', '--name', type=str, help='Name of project')
@click.option('-pw', '--password', type=str, help='Project password')
@click.option('-a', '--auth', type=str, help='Auth your request')
@click.command()
def create_project(name: str, password: str, auth: str):
	"""Create a new project"""
	if not name:
		click.echo("\nLooks like you might be missing some args, add `--help` to your command to see the options.\n")
	else:
		user_query = workspace_queries.get_billing_info_query
		req, json_data_user = utils.make_request(auth, user_query)
		plan = json_data_user['data']['user']['company']['billing']['plan']['title']
		proj_used = json_data_user['data']['user']['company']['billing']['projectQuantityUsed']
		if plan == 'Free' and proj_used == 1:
			click.echo("\nYou have maxed out your allowances, either delete a project then run the command again or upgrade for unlimited projects: https://marvelapp.com/plans \n")
		else:
			params = {'name': name,'password': password}
			if not password:
				params['password'] = ''
			query = project_queries.create_project_query
			r, json_data = utils.make_request(auth, query, params)

			if r.status_code != 200:
				click.echo('\n' + 'A new project could not be created at this time."' + '\n')
			else:
				click.echo('\n"%s" has been successfully created in your Marvel account \n' % name)

@click.option('-a', '--auth', type=str, help='Auth your request')
@click.command()
def get_personal_projects(auth: str):
	"""List all projects owned by you"""
	query = project_queries.get_all_personal_projects_query
	r, json_data = utils.make_request(auth, query)

	if r.status_code != 200:
		click.echo('\n' + 'Your personal projects could not be returned at this time."' + '\n')
	else:
		data = json_data['data']['user']['projects']['edges']
		urls = []
		for d in data:
			url = d['node']['prototypeUrl']
			urls.append(url)

		project_count = len(json_data['data']['user']['projects']['edges'])
		click.echo('\nYou have %s project(s):' % project_count)

		for url in urls:
			click.echo(url)

		click.echo("\n")



import click

from marvelcli import utils
from marvelcli.group import group_queries

@click.option('-g', '--group-pk', type=int, multiple=True, help='Use this flag for each group to be deleted')
@click.option('-a', '--auth', type=str, help='Auth your request')
@click.command()
def delete_groups(group_pk: list, auth: str):
	"""Delete a list of groups"""
	params = {'groupPks': group_pk}
	query = group_queries.delete_groups_query
	r, json_data = utils.make_request(auth, query, params)

	if r.status_code != 200:
		click.echo(json_data['data']['deleteGroups']['error']['message'])
	else:
		if not group_pk:
			click.echo("\nLooks like you might be missing some args, add `--help` to your command to see the options.\n")
		else:
			data_success = json_data['data']['deleteGroups']['succeeded']
			data_failed = json_data['data']['deleteGroups']['failed']

			if data_success:
				click.echo("\nThe following groups were deleted from your workspace successfully: %s" % data_success)

			if data_failed:
				click.echo('\nThe following groups could not be deleted from your workspace:')
				for f in data_failed:
					click.echo("%s  - %s" % (f.get('groupPk'), f.get('message')))

			click.echo("\n")

@click.option('-n', '--name', type=str, help='Name of group')
@click.option('-a', '--auth', type=str, help='Auth your request')
@click.command()
def create_group(name: str, auth: str):
	"""Create a group"""
	params = {'name': name}
	query = group_queries.create_group_query
	r, json_data = utils.make_request(auth, query, params)

	if r.status_code == 200:
		if not json_data['data']['createTeam']['ok']:
			click.echo('\n' + json_data['data']['createTeam']['error']['message'] + '\n')
		else:
			click.echo('\nThe group "%s" has been successfully created in your Marvel account\n' % name)
	else:
		click.echo("\nTry 'marvelcli create-group --help' to make sure you are not missing any args.\n")

@click.option('-g', '--group-pk', type=int, help='Pk of the group you want to add members to')
@click.option('-e', '--email', type=str, multiple=True, help='Use this flag for each email address you want added to your group')
@click.option('-a', '--auth', type=str, help='Auth your request')
@click.command()
def add_members_to_group(group_pk: int, email: list, auth: str):
	"""Add members to a group"""
	params = {'teamPk': group_pk,'emails': email}
	query = group_queries.add_members_query
	r, json_data = utils.make_request(auth, query, params)

	if r.status_code != 200:
		if not group_pk:
			click.echo("\nLooks like you might be missing some args, add `--help` to your command to see the options.\n")
		else:
			click.echo(json_data['data']['addMembersToTeam']['error']['message'])
	else:
		if not email:
			click.echo("\nLooks like you might be missing some args, add `--help` to your command to see the options.\n")
		else:
			data_success = json_data['data']['addMembersToTeam']['succeeded']
			data_failed = json_data['data']['addMembersToTeam']['failed']
			if data_success:
				successful_emails = []
				for s in data_success:
					successful_emails.append(s.get('email'))

				click.echo("\nThe following people were successfully added to group %s: %s" % (group_pk, ', '.join(successful_emails)))

			if data_failed:
				click.echo('\nThe following people could not be added to group %s for the following reasons:' % (group_pk))
				for f in data_failed:
					click.echo("%s  - %s" % (f.get('email'), f.get('message')))

			click.echo("\n")

@click.option('-g', '--group-pk', type=int, help='Pk of the group you want to remove members from')
@click.option('-e', '--email', type=str, multiple=True, help='Use this flag for each email address you want removed from your group')
@click.option('-a', '--auth', type=str, help='Auth your request')
@click.command()
def remove_members_from_group(group_pk: int, email: list, auth: str):
	"""Remove members from a group"""
	params = {'teamPk': group_pk,'emails': email}
	query = group_queries.remove_members_query
	r, json_data = utils.make_request(auth, query, params)

	if r.status_code != 200:
		if not group_pk:
			click.echo("\nLooks like you might be missing some args, add `--help` to your command to see the options.\n")
		else:
			click.echo(json_data['data']['removeMembersFromTeam']['error']['message'])
	else:
		if not email:
			click.echo("\nLooks like you might be missing some args, add `--help` to your command to see the options.\n")
		else:
			data_success = json_data['data']['removeMembersFromTeam']['succeeded']
			data_failed = json_data['data']['removeMembersFromTeam']['failed']

			if data_success:
				click.echo("\nThe following people were successfully removed from group %s: %s" % (group_pk, data_success))

			if data_failed:
				click.echo('\nThe following people could not be removed from group %s:' % (group_pk))
				for f in data_failed:
					click.echo("%s  - %s" % (f.get('email'), f.get('message')))

			click.echo("\n")

@click.option('-g', '--group-pk', type=int, help='Pk of the group you want to update the name for')
@click.option('-n', '--name', type=str, help='New name for your group')
@click.option('-a', '--auth', type=str, help='Auth your request')
@click.command()
def update_group_name(group_pk: int, name: str, auth: str):
	"""Update a group name"""
	params = {'pk': group_pk, 'name': name}
	query = group_queries.update_group_name_query
	r, json_data = utils.make_request(auth, query, params)

	if r.status_code == 200:
		if not json_data['data']['updateGroup']['ok']:
			click.echo('\n' + json_data['data']['updateGroup']['error']['message'])
		else:
			click.echo("\nThe name of the group was updated successfully to '%s'\n" % name)
	else:
		click.echo("\nTry 'marvelcli update_group_name --help' to make sure you are not missing any args.\n")



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="marvelapp-cli",
    version="0.1.5",
    author="Sophie Fitzpatrick",
    author_email="sophierfitzpatrick@gmail.com",
    description="A CLI wrapper for Marvelapp",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/sophiefitzpatrick/marvelcli/archive/v_0.1.5.tar.gz",
    packages=setuptools.find_packages(),
    install_requires=[
        'requests',
        'os'
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    entry_points='''
        [console_scripts]
        marvelcli=marvelcli.marvelcli:marvelcli
    ''',
)
